# luxsci.EmailApi

All URIs are relative to *https://rest.luxsci.com/perl/api/v2*, unless a hostname is provided ([see README](../README.md#documentation-for-api-endpoints))

Method | HTTP request | Description
------------- | ------------- | -------------
[**create_custom_bounce_domain**](EmailApi.md#create_custom_bounce_domain) | **POST** /account/{accountId}/bounce_domain | 
[**create_dkim**](EmailApi.md#create_dkim) | **POST** /account/{accountId}/dkim | 
[**delete_dkim**](EmailApi.md#delete_dkim) | **DELETE** /account/{accountId}/dkim/{domainName} | 
[**delete_email_auto_responder**](EmailApi.md#delete_email_auto_responder) | **DELETE** /user/{username}/email/ar/{id} | 
[**get_dkim_details**](EmailApi.md#get_dkim_details) | **GET** /account/{accountId}/dkim/{domainName} | 
[**get_dkim_report**](EmailApi.md#get_dkim_report) | **GET** /account/{accountId}/dkim | 
[**get_email_auto_responders**](EmailApi.md#get_email_auto_responders) | **GET** /user/{username}/email/ar | 
[**new_email_auto_responder**](EmailApi.md#new_email_auto_responder) | **POST** /user/{username}/email/ar | 
[**retrieve_secure_line_recipient_list_encryption_data**](EmailApi.md#retrieve_secure_line_recipient_list_encryption_data) | **POST** /user/{username}/email/compose/secureline/recipients | 
[**update_email_forwarding**](EmailApi.md#update_email_forwarding) | **PUT** /user/{username}/email/forwarding | 

# **create_custom_bounce_domain**
> create_custom_bounce_domain(account_id, body=body)



Add a new Custom Bounce Domain to the account.  The bounce domain must be a subdomain of the from domain in question, have DKIM configured already, and the DNS must already be a CNAME to any of the target domains listed in the Custom Bounce Domains user interface area. {{ACL: Account: Domains - Manage}}

### Example
```python
from __future__ import print_function
import time
import luxsci
from luxsci.rest import ApiException
from pprint import pprint

# create an instance of the API class
secret_key = "SECRET_KEY"
token = "TOKEN"

luxsci_client = luxci.Client(secret_key, token)
api_instance = luxsci_client.EmailApi

account_id = 'account_id_example' # str | 
body = luxsci.AccountIdBounceDomainBody() # AccountIdBounceDomainBody |  (optional)

try:
    api_instance.create_custom_bounce_domain(account_id, body=body)
except ApiException as e:
    print("Exception when calling EmailApi->create_custom_bounce_domain: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **account_id** | **str**|  | 
 **body** | [**AccountIdBounceDomainBody**](AccountIdBounceDomainBody.md)|  | [optional] 

### Return type

void (empty response body)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: Not defined

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **create_dkim**
> create_dkim(account_id, body=body)



Create a new DKIM configuration in your account. {{ACL: Account: Domains - Manage}}

### Example
```python
from __future__ import print_function
import time
import luxsci
from luxsci.rest import ApiException
from pprint import pprint

# create an instance of the API class
secret_key = "SECRET_KEY"
token = "TOKEN"

luxsci_client = luxci.Client(secret_key, token)
api_instance = luxsci_client.EmailApi

account_id = 'account_id_example' # str | 
body = luxsci.AccountIdDkimBody() # AccountIdDkimBody |  (optional)

try:
    api_instance.create_dkim(account_id, body=body)
except ApiException as e:
    print("Exception when calling EmailApi->create_dkim: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **account_id** | **str**|  | 
 **body** | [**AccountIdDkimBody**](AccountIdDkimBody.md)|  | [optional] 

### Return type

void (empty response body)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: Not defined

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **delete_dkim**
> InlineResponse201 delete_dkim(account_id, domain_name)



Remove a DKIM definition from your account. {{ACL: Account: Domains - Manage}}

### Example
```python
from __future__ import print_function
import time
import luxsci
from luxsci.rest import ApiException
from pprint import pprint

# create an instance of the API class
secret_key = "SECRET_KEY"
token = "TOKEN"

luxsci_client = luxci.Client(secret_key, token)
api_instance = luxsci_client.EmailApi

account_id = 'account_id_example' # str | 
domain_name = 'domain_name_example' # str | 

try:
    api_response = api_instance.delete_dkim(account_id, domain_name)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling EmailApi->delete_dkim: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **account_id** | **str**|  | 
 **domain_name** | **str**|  | 

### Return type

[**InlineResponse201**](InlineResponse201.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **delete_email_auto_responder**
> InlineResponse201 delete_email_auto_responder(username, id)



Delete an email auto-responder number `id` that belongs to the user. {{ACL:User Email - Auto-Responders}}

### Example
```python
from __future__ import print_function
import time
import luxsci
from luxsci.rest import ApiException
from pprint import pprint

# create an instance of the API class
secret_key = "SECRET_KEY"
token = "TOKEN"

luxsci_client = luxci.Client(secret_key, token)
api_instance = luxsci_client.EmailApi

username = 'username_example' # str | 
id = 'id_example' # str | 

try:
    api_response = api_instance.delete_email_auto_responder(username, id)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling EmailApi->delete_email_auto_responder: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **str**|  | 
 **id** | **str**|  | 

### Return type

[**InlineResponse201**](InlineResponse201.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_dkim_details**
> InlineResponse20062 get_dkim_details(account_id, domain_name)



Get information about a specific DKIM configuration. This is the same as the “Get DKIM Report,” except that it returns data for 1 specific domain.  {{ACL: Account: Domains - Manage}}

### Example
```python
from __future__ import print_function
import time
import luxsci
from luxsci.rest import ApiException
from pprint import pprint

# create an instance of the API class
secret_key = "SECRET_KEY"
token = "TOKEN"

luxsci_client = luxci.Client(secret_key, token)
api_instance = luxsci_client.EmailApi

account_id = 'account_id_example' # str | 
domain_name = 'domain_name_example' # str | 

try:
    api_response = api_instance.get_dkim_details(account_id, domain_name)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling EmailApi->get_dkim_details: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **account_id** | **str**|  | 
 **domain_name** | **str**|  | 

### Return type

[**InlineResponse20062**](InlineResponse20062.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_dkim_report**
> InlineResponse20061 get_dkim_report(account_id)



Get information about your DKIM configurations. {{ACL: Account: Domains - Manage}}

### Example
```python
from __future__ import print_function
import time
import luxsci
from luxsci.rest import ApiException
from pprint import pprint

# create an instance of the API class
secret_key = "SECRET_KEY"
token = "TOKEN"

luxsci_client = luxci.Client(secret_key, token)
api_instance = luxsci_client.EmailApi

account_id = 'account_id_example' # str | 

try:
    api_response = api_instance.get_dkim_report(account_id)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling EmailApi->get_dkim_report: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **account_id** | **str**|  | 

### Return type

[**InlineResponse20061**](InlineResponse20061.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_email_auto_responders**
> InlineResponse2008 get_email_auto_responders(username)



Return all email auto-responders owned by this user. {{ACL:User Email - Auto-Responders}}

### Example
```python
from __future__ import print_function
import time
import luxsci
from luxsci.rest import ApiException
from pprint import pprint

# create an instance of the API class
secret_key = "SECRET_KEY"
token = "TOKEN"

luxsci_client = luxci.Client(secret_key, token)
api_instance = luxsci_client.EmailApi

username = 'username_example' # str | 

try:
    api_response = api_instance.get_email_auto_responders(username)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling EmailApi->get_email_auto_responders: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **str**|  | 

### Return type

[**InlineResponse2008**](InlineResponse2008.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **new_email_auto_responder**
> InlineResponse2009 new_email_auto_responder(username, body=body)



Create a new email auto-responer. {{ACL:User Email - Auto-Responders}}

### Example
```python
from __future__ import print_function
import time
import luxsci
from luxsci.rest import ApiException
from pprint import pprint

# create an instance of the API class
secret_key = "SECRET_KEY"
token = "TOKEN"

luxsci_client = luxci.Client(secret_key, token)
api_instance = luxsci_client.EmailApi

username = 'username_example' # str | 
body = luxsci.EmailArBody() # EmailArBody |  (optional)

try:
    api_response = api_instance.new_email_auto_responder(username, body=body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling EmailApi->new_email_auto_responder: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **str**|  | 
 **body** | [**EmailArBody**](EmailArBody.md)|  | [optional] 

### Return type

[**InlineResponse2009**](InlineResponse2009.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **retrieve_secure_line_recipient_list_encryption_data**
> InlineResponse20011 retrieve_secure_line_recipient_list_encryption_data(username, body=body)



When composing an email message, you may have a list of recipients and want to know what kind of encryption, if any, would be used for each recipient when it is finally sent out with SecureLine encryption. E.g. this can be used to (a) inform the sender of what encryption will be used, and (b) to discover ahead of time if there are some recipients for which a message cannot yet be encrypted (possible, for example, if SecureLine Escrow is setup to use question and answer authentication without a default fall-back question and answer).  It is good to use this method before sending an encrypted message – so you can modify your recipient list and/or add additional required encryption information before sending.  Note: This is a RPC-style call and hence uses a POST method even though we are “getting data”. We are interacting with the system rather than querying a specific resource. {{ACL: User Email - Sending}}

### Example
```python
from __future__ import print_function
import time
import luxsci
from luxsci.rest import ApiException
from pprint import pprint

# create an instance of the API class
secret_key = "SECRET_KEY"
token = "TOKEN"

luxsci_client = luxci.Client(secret_key, token)
api_instance = luxsci_client.EmailApi

username = 'username_example' # str | 
body = luxsci.SecurelineRecipientsBody() # SecurelineRecipientsBody |  (optional)

try:
    api_response = api_instance.retrieve_secure_line_recipient_list_encryption_data(username, body=body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling EmailApi->retrieve_secure_line_recipient_list_encryption_data: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **str**|  | 
 **body** | [**SecurelineRecipientsBody**](SecurelineRecipientsBody.md)|  | [optional] 

### Return type

[**InlineResponse20011**](InlineResponse20011.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **update_email_forwarding**
> InlineResponse201 update_email_forwarding(username, body=body)



This function allows you to alter the email forwarding (and denial/deletion) settings for the user. {{ACL:User Email - Forwarding}}

### Example
```python
from __future__ import print_function
import time
import luxsci
from luxsci.rest import ApiException
from pprint import pprint

# create an instance of the API class
secret_key = "SECRET_KEY"
token = "TOKEN"

luxsci_client = luxci.Client(secret_key, token)
api_instance = luxsci_client.EmailApi

username = 'username_example' # str | 
body = luxsci.EmailForwardingBody() # EmailForwardingBody |  (optional)

try:
    api_response = api_instance.update_email_forwarding(username, body=body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling EmailApi->update_email_forwarding: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **str**|  | 
 **body** | [**EmailForwardingBody**](EmailForwardingBody.md)|  | [optional] 

### Return type

[**InlineResponse201**](InlineResponse201.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

