# luxsci.WebAidesApi

All URIs are relative to *https://rest.luxsci.com/perl/api/v2*, unless a hostname is provided ([see README](../README.md#documentation-for-api-endpoints))

Method | HTTP request | Description
------------- | ------------- | -------------
[**add_update_web_aide_entries**](WebAidesApi.md#add_update_web_aide_entries) | **POST** /user/{username}/webaides/{webaide_type}/{webaide_id}/entries/import | 
[**delete_web_aide**](WebAidesApi.md#delete_web_aide) | **DELETE** /user/{username}/webaides/{webaide_type}/{webaide_id} | 
[**delete_web_aide_entries**](WebAidesApi.md#delete_web_aide_entries) | **POST** /user/{username}/webaides/{webaide_type}/{webaide_id}/entries/delete | 
[**delete_web_aide_entry**](WebAidesApi.md#delete_web_aide_entry) | **DELETE** /user/{username}/webaides/{webaide_type}/{webaide_id}/{entry_id} | 
[**get_calendar_entries_date_range**](WebAidesApi.md#get_calendar_entries_date_range) | **GET** /user/{username}/webaides/calendar/{webaide_id}/entries/date_range | 
[**get_web_aide**](WebAidesApi.md#get_web_aide) | **GET** /user/{username}/webaides/{webaide_type}/{webaide_id} | 
[**get_web_aide_changes**](WebAidesApi.md#get_web_aide_changes) | **GET** /user/{username}/webaides/{webaide_type}/{webaide_id}/entries/changes | 
[**get_web_aide_entries**](WebAidesApi.md#get_web_aide_entries) | **GET** /user/{username}/webaides/{webaide_type}/{webaide_id}/entries | 
[**get_web_aide_entry**](WebAidesApi.md#get_web_aide_entry) | **GET** /user/{username}/webaides/{webaide_type}/{webaide_id}/{entry_id} | 
[**get_web_aides**](WebAidesApi.md#get_web_aides) | **GET** /user/{username}/webaides/{webaide_type} | 
[**new_web_aide**](WebAidesApi.md#new_web_aide) | **POST** /user/{username}/webaides/{webaide_type} | 
[**new_web_aide_entry**](WebAidesApi.md#new_web_aide_entry) | **POST** /user/{username}/webaides/{webaide_type}/{webaide_id} | 
[**update_web_aide_entry**](WebAidesApi.md#update_web_aide_entry) | **PUT** /user/{username}/webaides/{webaide_type}/{webaide_id}/{entry_id} | 

# **add_update_web_aide_entries**
> InlineResponse20031 add_update_web_aide_entries(username, webaide_type, webaide_id, body=body)



Add/update multiple entries of a WebAide all at once.  Address Book Imports: SecureLine data can be sent in this way as well (i.e. Escrow question and answer, PGP key, S/MIME key, etc.). SecureLine data is imported if and only if the “SecureLine Mode” field is present and not empty for an entry. Any entries that are updated and for which “SecureLine Mode” is left blank, will have their existing SecureLine settings left “as-is”.  Note: Each WebAide is limited to 25,000 entries by default. If your WebAide has this many entries (or more), then this AddUpdateWebAideEntries command will return an error (even if you are only intending to do updates). If you need larger WebAides, please contact support. Very large WebAides may require use of a dedicated server.  See also [WebAide definitions](/rest-api/webaides.html).  {{ACL: Access to that specific type of WebAides; Add/Update Accessible WebAides and Entries }}

### Example
```python
from __future__ import print_function
import time
import luxsci
from luxsci.rest import ApiException
from pprint import pprint

# create an instance of the API class
secret_key = "SECRET_KEY"
token = "TOKEN"

luxsci_client = luxci.Client(secret_key, token)
api_instance = luxsci_client.WebAidesApi

username = 'username_example' # str | 
webaide_type = 'webaide_type_example' # str | 
webaide_id = 'webaide_id_example' # str | 
body = luxsci.EntriesImportBody() # EntriesImportBody |  (optional)

try:
    api_response = api_instance.add_update_web_aide_entries(username, webaide_type, webaide_id, body=body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling WebAidesApi->add_update_web_aide_entries: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **str**|  | 
 **webaide_type** | **str**|  | 
 **webaide_id** | **str**|  | 
 **body** | [**EntriesImportBody**](EntriesImportBody.md)|  | [optional] 

### Return type

[**InlineResponse20031**](InlineResponse20031.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **delete_web_aide**
> InlineResponse201 delete_web_aide(username, webaide_type, webaide_id)



Delete a WebAide of type `webaide_type` whose unique ID is `webaide_id`. This WebAide must be owned by the user in question. See also [WebAide definitions](/rest-api/webaides.html).  {{ACL: Access to that specific type of WebAides; Delete Accessible WebAides and Entries }}

### Example
```python
from __future__ import print_function
import time
import luxsci
from luxsci.rest import ApiException
from pprint import pprint

# create an instance of the API class
secret_key = "SECRET_KEY"
token = "TOKEN"

luxsci_client = luxci.Client(secret_key, token)
api_instance = luxsci_client.WebAidesApi

username = 'username_example' # str | 
webaide_type = 'webaide_type_example' # str | 
webaide_id = 'webaide_id_example' # str | 

try:
    api_response = api_instance.delete_web_aide(username, webaide_type, webaide_id)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling WebAidesApi->delete_web_aide: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **str**|  | 
 **webaide_type** | **str**|  | 
 **webaide_id** | **str**|  | 

### Return type

[**InlineResponse201**](InlineResponse201.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **delete_web_aide_entries**
> InlineResponse20029 delete_web_aide_entries(username, webaide_type, webaide_id, body=body)



Delete multiple entries from a WebAide all at once. (Since we are not deleting an individual entity at a specific address, this is a POST instead of a DELETE method). See also [WebAide definitions](/rest-api/webaides.html). {{ACL: Access to that specific type of WebAides; Delete Accessible WebAides and Entries }}

### Example
```python
from __future__ import print_function
import time
import luxsci
from luxsci.rest import ApiException
from pprint import pprint

# create an instance of the API class
secret_key = "SECRET_KEY"
token = "TOKEN"

luxsci_client = luxci.Client(secret_key, token)
api_instance = luxsci_client.WebAidesApi

username = 'username_example' # str | 
webaide_type = 'webaide_type_example' # str | 
webaide_id = 'webaide_id_example' # str | 
body = luxsci.EntriesDeleteBody() # EntriesDeleteBody |  (optional)

try:
    api_response = api_instance.delete_web_aide_entries(username, webaide_type, webaide_id, body=body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling WebAidesApi->delete_web_aide_entries: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **str**|  | 
 **webaide_type** | **str**|  | 
 **webaide_id** | **str**|  | 
 **body** | [**EntriesDeleteBody**](EntriesDeleteBody.md)|  | [optional] 

### Return type

[**InlineResponse20029**](InlineResponse20029.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **delete_web_aide_entry**
> InlineResponse20026 delete_web_aide_entry(username, webaide_type, webaide_id, entry_id)



Delete an existing WebAide Entry. See also [WebAide definitions](/rest-api/webaides.html). {{ACL: Access to that specific type of WebAides; Delete Accessible WebAides and Entries }}

### Example
```python
from __future__ import print_function
import time
import luxsci
from luxsci.rest import ApiException
from pprint import pprint

# create an instance of the API class
secret_key = "SECRET_KEY"
token = "TOKEN"

luxsci_client = luxci.Client(secret_key, token)
api_instance = luxsci_client.WebAidesApi

username = 'username_example' # str | 
webaide_type = 'webaide_type_example' # str | 
webaide_id = 'webaide_id_example' # str | 
entry_id = 'entry_id_example' # str | 

try:
    api_response = api_instance.delete_web_aide_entry(username, webaide_type, webaide_id, entry_id)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling WebAidesApi->delete_web_aide_entry: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **str**|  | 
 **webaide_type** | **str**|  | 
 **webaide_id** | **str**|  | 
 **entry_id** | **str**|  | 

### Return type

[**InlineResponse20026**](InlineResponse20026.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_calendar_entries_date_range**
> InlineResponse20028 get_calendar_entries_date_range(username, webaide_id, before, _from, entries=entries)



Gets a list of entries in a specified Calendar WebAide that fall within a specified range of dates. For recurring entries, the entry will be returned if any of its instances fall within the specified date range. The date range is taken to be dates in GMT. See also [WebAide definitions](/rest-api/webaides.html).  {{ACL: Access to WebAide Calendars; Read Accessible WebAides and Entries }}

### Example
```python
from __future__ import print_function
import time
import luxsci
from luxsci.rest import ApiException
from pprint import pprint

# create an instance of the API class
secret_key = "SECRET_KEY"
token = "TOKEN"

luxsci_client = luxci.Client(secret_key, token)
api_instance = luxsci_client.WebAidesApi

username = 'username_example' # str | 
webaide_id = 'webaide_id_example' # str | 
before = 'before_example' # str | DATE: “YYYY-MM-DD” in GMT (where 00:00:00 GMT is implied) Required. Entries that contain events before this date.
_from = '_from_example' # str | DATE: “YYYY-MM-DD” in GMT (where 00:00:00 GMT is implied)<br><br>Required. Entries that contain events on or after this date.
entries = 'entries_example' # str | Comma-delimited list of entry Unique IDs. e.g. “10786,77892,23”<br><br>Optional. If included, the search is restricted to only entries in this list.<br><br>Note, if you want to use a very long list of entries, you might want to use several requests so that you do not exceed the maximum URL query string size of 8190 bytes. (optional)

try:
    api_response = api_instance.get_calendar_entries_date_range(username, webaide_id, before, _from, entries=entries)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling WebAidesApi->get_calendar_entries_date_range: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **str**|  | 
 **webaide_id** | **str**|  | 
 **before** | **str**| DATE: “YYYY-MM-DD” in GMT (where 00:00:00 GMT is implied) Required. Entries that contain events before this date. | 
 **_from** | **str**| DATE: “YYYY-MM-DD” in GMT (where 00:00:00 GMT is implied)&lt;br&gt;&lt;br&gt;Required. Entries that contain events on or after this date. | 
 **entries** | **str**| Comma-delimited list of entry Unique IDs. e.g. “10786,77892,23”&lt;br&gt;&lt;br&gt;Optional. If included, the search is restricted to only entries in this list.&lt;br&gt;&lt;br&gt;Note, if you want to use a very long list of entries, you might want to use several requests so that you do not exceed the maximum URL query string size of 8190 bytes. | [optional] 

### Return type

[**InlineResponse20028**](InlineResponse20028.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_web_aide**
> InlineResponse20022 get_web_aide(username, webaide_type, webaide_id, changes=changes)



This call is like `getWebAides`, except that the call is simplified and targeted at a specific, single WebAide. See also [WebAide definitions](/rest-api/webaides.html). {{ACL: Access to that specific type of WebAides; Read Accessible WebAides and Entries }}

### Example
```python
from __future__ import print_function
import time
import luxsci
from luxsci.rest import ApiException
from pprint import pprint

# create an instance of the API class
secret_key = "SECRET_KEY"
token = "TOKEN"

luxsci_client = luxci.Client(secret_key, token)
api_instance = luxsci_client.WebAidesApi

username = 'username_example' # str | 
webaide_type = 'webaide_type_example' # str | 
webaide_id = 'webaide_id_example' # str | 
changes = 'changes_example' # str | Optional. DateTime in GMT in the format: YYYY-MM-DD HH:MM:SS. If this is provided, a sub call to “GetWebAideChanges” will be made for each returned WebAide, giving you summary counts of numbers of entries and adds/updates/deletes since the specified date.<br><br>Specify an old date (e.g. “2000-01-01”) if all you care about is the total number of entries.<br><br>Use of “changes” is the recommended way to get the number of entries in one or more WebAides in an efficient manner. (optional)

try:
    api_response = api_instance.get_web_aide(username, webaide_type, webaide_id, changes=changes)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling WebAidesApi->get_web_aide: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **str**|  | 
 **webaide_type** | **str**|  | 
 **webaide_id** | **str**|  | 
 **changes** | **str**| Optional. DateTime in GMT in the format: YYYY-MM-DD HH:MM:SS. If this is provided, a sub call to “GetWebAideChanges” will be made for each returned WebAide, giving you summary counts of numbers of entries and adds/updates/deletes since the specified date.&lt;br&gt;&lt;br&gt;Specify an old date (e.g. “2000-01-01”) if all you care about is the total number of entries.&lt;br&gt;&lt;br&gt;Use of “changes” is the recommended way to get the number of entries in one or more WebAides in an efficient manner. | [optional] 

### Return type

[**InlineResponse20022**](InlineResponse20022.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_web_aide_changes**
> InlineResponse20030 get_web_aide_changes(username, webaide_type, webaide_id, modified)



Return all WebAide entries added, changed, or deleted since a particular time. See also [WebAide definitions](/rest-api/webaides.html).  {{ACL: Access to that specific type of WebAides; Read Accessible WebAides and Entries }}

### Example
```python
from __future__ import print_function
import time
import luxsci
from luxsci.rest import ApiException
from pprint import pprint

# create an instance of the API class
secret_key = "SECRET_KEY"
token = "TOKEN"

luxsci_client = luxci.Client(secret_key, token)
api_instance = luxsci_client.WebAidesApi

username = 'username_example' # str | 
webaide_type = 'webaide_type_example' # str | 
webaide_id = 'webaide_id_example' # str | 
modified = 'modified_example' # str | Timestamp “YYYYMMDDHHMMSS” in GMT or “YYYY-MM-DD HH:MM:SS” in GMT<br><br>Return all WebAide entries added, changed, or deleted since this timestamp. If you specify “0” here, it will return a list of all entries that exist now and all that have been deleted.

try:
    api_response = api_instance.get_web_aide_changes(username, webaide_type, webaide_id, modified)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling WebAidesApi->get_web_aide_changes: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **str**|  | 
 **webaide_type** | **str**|  | 
 **webaide_id** | **str**|  | 
 **modified** | **str**| Timestamp “YYYYMMDDHHMMSS” in GMT or “YYYY-MM-DD HH:MM:SS” in GMT&lt;br&gt;&lt;br&gt;Return all WebAide entries added, changed, or deleted since this timestamp. If you specify “0” here, it will return a list of all entries that exist now and all that have been deleted. | 

### Return type

[**InlineResponse20030**](InlineResponse20030.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_web_aide_entries**
> InlineResponse20027 get_web_aide_entries(username, webaide_type, webaide_id, entries=entries, limit=limit, resume=resume, secureline=secureline, showcomplete=showcomplete, sort=sort, start=start, timezone=timezone)



Retrieve the detailed contents of all WebAide entries matching a query. See also [WebAide definitions](/rest-api/webaides.html).  {{ACL: Access to that specific type of WebAides; Read Accessible WebAides and Entries }}

### Example
```python
from __future__ import print_function
import time
import luxsci
from luxsci.rest import ApiException
from pprint import pprint

# create an instance of the API class
secret_key = "SECRET_KEY"
token = "TOKEN"

luxsci_client = luxci.Client(secret_key, token)
api_instance = luxsci_client.WebAidesApi

username = 'username_example' # str | 
webaide_type = 'webaide_type_example' # str | 
webaide_id = 'webaide_id_example' # str | 
entries = ['entries_example'] # list[str] | Optional. Comma-delimited list of entry Unique IDs. e.g. “10786,77892,23”.  If included, the search is restricted to only entries in this list.  Note, if you want to use a very long list of entries, you might want to use several requests so that you do not exceed the maximum URL query string size of 8190 bytes. (optional)
limit = 500 # int | Optional. Integer 1 to 500. How many entries to return (maximum). Default is 500. (optional) (default to 500)
resume = 0 # int | Integer:1 or 0. If 0 (the default), begin a new search. If 1, continue the previous search. When returning successive “pages” or entries, use resume for faster and more consistent results. (optional) (default to 0)
secureline = 56 # int | Integer 1 or 0 If specified as ‘1’, SecureLine-specific Address Book fields are included in the export. I.e., this includes the SecureLine Escrow Question/Answer pair and/or PGP and S/MIME public keys. (optional)
showcomplete = 56 # int | Integer 1 or 0 If specified as ‘1’, get completed tasks for ‘Tasks’ WebAides. By default, only uncompleted tasks are returned. (optional)
sort = 'sort_example' # str | Optional method by which the returned entries should be sorted. (optional)
start = 0 # int | Optional. The default is 0. Index in the list of all entries from which to start the result set. Use this to return successive “pages” of entries. (optional) (default to 0)
timezone = 'timezone_example' # str | Time zone code. The time zone to use for Calendar/Task dates and times. The user’s default time zone is used if no time zone is specified. (optional)

try:
    api_response = api_instance.get_web_aide_entries(username, webaide_type, webaide_id, entries=entries, limit=limit, resume=resume, secureline=secureline, showcomplete=showcomplete, sort=sort, start=start, timezone=timezone)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling WebAidesApi->get_web_aide_entries: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **str**|  | 
 **webaide_type** | **str**|  | 
 **webaide_id** | **str**|  | 
 **entries** | [**list[str]**](str.md)| Optional. Comma-delimited list of entry Unique IDs. e.g. “10786,77892,23”.  If included, the search is restricted to only entries in this list.  Note, if you want to use a very long list of entries, you might want to use several requests so that you do not exceed the maximum URL query string size of 8190 bytes. | [optional] 
 **limit** | **int**| Optional. Integer 1 to 500. How many entries to return (maximum). Default is 500. | [optional] [default to 500]
 **resume** | **int**| Integer:1 or 0. If 0 (the default), begin a new search. If 1, continue the previous search. When returning successive “pages” or entries, use resume for faster and more consistent results. | [optional] [default to 0]
 **secureline** | **int**| Integer 1 or 0 If specified as ‘1’, SecureLine-specific Address Book fields are included in the export. I.e., this includes the SecureLine Escrow Question/Answer pair and/or PGP and S/MIME public keys. | [optional] 
 **showcomplete** | **int**| Integer 1 or 0 If specified as ‘1’, get completed tasks for ‘Tasks’ WebAides. By default, only uncompleted tasks are returned. | [optional] 
 **sort** | **str**| Optional method by which the returned entries should be sorted. | [optional] 
 **start** | **int**| Optional. The default is 0. Index in the list of all entries from which to start the result set. Use this to return successive “pages” of entries. | [optional] [default to 0]
 **timezone** | **str**| Time zone code. The time zone to use for Calendar/Task dates and times. The user’s default time zone is used if no time zone is specified. | [optional] 

### Return type

[**InlineResponse20027**](InlineResponse20027.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_web_aide_entry**
> InlineResponse2003 get_web_aide_entry(username, webaide_type, webaide_id, entry_id)



Retrieve the detailed contents of a specific WebAide entry. See also [WebAide definitions](/rest-api/webaides.html). {{ACL: Access to that specific type of WebAides; Read Accessible WebAides and Entries }}

### Example
```python
from __future__ import print_function
import time
import luxsci
from luxsci.rest import ApiException
from pprint import pprint

# create an instance of the API class
secret_key = "SECRET_KEY"
token = "TOKEN"

luxsci_client = luxci.Client(secret_key, token)
api_instance = luxsci_client.WebAidesApi

username = 'username_example' # str | 
webaide_type = 'webaide_type_example' # str | 
webaide_id = 'webaide_id_example' # str | 
entry_id = 'entry_id_example' # str | 

try:
    api_response = api_instance.get_web_aide_entry(username, webaide_type, webaide_id, entry_id)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling WebAidesApi->get_web_aide_entry: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **str**|  | 
 **webaide_type** | **str**|  | 
 **webaide_id** | **str**|  | 
 **entry_id** | **str**|  | 

### Return type

[**InlineResponse2003**](InlineResponse2003.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_web_aides**
> InlineResponse20022 get_web_aides(username, webaide_type, subscribed=subscribed, ids=ids, permissions=permissions, modified=modified, changes=changes)



Return a list of all WebAides accessible to the specified user, that are also of the indicated type. You can use the query string to add filters to narrow down the results. See also [WebAide definitions](/rest-api/webaides.html). {{ACL: Access to that specific type of WebAides; Read Accessible WebAides and Entries }}

### Example
```python
from __future__ import print_function
import time
import luxsci
from luxsci.rest import ApiException
from pprint import pprint

# create an instance of the API class
secret_key = "SECRET_KEY"
token = "TOKEN"

luxsci_client = luxci.Client(secret_key, token)
api_instance = luxsci_client.WebAidesApi

username = 'username_example' # str | 
webaide_type = 'webaide_type_example' # str | 
subscribed = 'subscribed_example' # str | Filter by WebAide subscription status<ul><li>all - select all</li><li>subscribed - return those subscribed</li><li>unsubscribed - return those not subscribed</li><li>tosync - return those tagged for synchronization with MobileSync.</li> (optional)
ids = ['ids_example'] # list[str] | List of the numerical WebAide IDs eligible to be returned. (optional)
permissions = ['permissions_example'] # list[str] | Values can include those in the webaide_permission list. Select only WebAides where the user has all of the indicated permissions (optional)
modified = 'modified_example' # str | DateTime in GMT in the format: YYYY-MM-DD HH:MM:SS. Return all WebAides that have had any entry created, deleted, or modified on or after this date and time. Values can include those in the webaide_permission list. (optional)
changes = 'changes_example' # str | Optional. DateTime in GMT in the format: YYYY-MM-DD HH:MM:SS. If this is provided, a sub call to “GetWebAideChanges” will be made for each returned WebAide, giving you summary counts of numbers of entries and adds/ updates/deletes since the specified date.<br><br>Specify an old date (e.g. “2000-01-01”) if all you care about is the total number of entries.<br><br>Use of “changes” is the recommended way to get the number of entries in one or more WebAides in an efficient manner. (optional)

try:
    api_response = api_instance.get_web_aides(username, webaide_type, subscribed=subscribed, ids=ids, permissions=permissions, modified=modified, changes=changes)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling WebAidesApi->get_web_aides: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **str**|  | 
 **webaide_type** | **str**|  | 
 **subscribed** | **str**| Filter by WebAide subscription status&lt;ul&gt;&lt;li&gt;all - select all&lt;/li&gt;&lt;li&gt;subscribed - return those subscribed&lt;/li&gt;&lt;li&gt;unsubscribed - return those not subscribed&lt;/li&gt;&lt;li&gt;tosync - return those tagged for synchronization with MobileSync.&lt;/li&gt; | [optional] 
 **ids** | [**list[str]**](str.md)| List of the numerical WebAide IDs eligible to be returned. | [optional] 
 **permissions** | [**list[str]**](str.md)| Values can include those in the webaide_permission list. Select only WebAides where the user has all of the indicated permissions | [optional] 
 **modified** | **str**| DateTime in GMT in the format: YYYY-MM-DD HH:MM:SS. Return all WebAides that have had any entry created, deleted, or modified on or after this date and time. Values can include those in the webaide_permission list. | [optional] 
 **changes** | **str**| Optional. DateTime in GMT in the format: YYYY-MM-DD HH:MM:SS. If this is provided, a sub call to “GetWebAideChanges” will be made for each returned WebAide, giving you summary counts of numbers of entries and adds/ updates/deletes since the specified date.&lt;br&gt;&lt;br&gt;Specify an old date (e.g. “2000-01-01”) if all you care about is the total number of entries.&lt;br&gt;&lt;br&gt;Use of “changes” is the recommended way to get the number of entries in one or more WebAides in an efficient manner. | [optional] 

### Return type

[**InlineResponse20022**](InlineResponse20022.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **new_web_aide**
> InlineResponse20023 new_web_aide(username, webaide_type, body=body)



Create a new WebAide of type webaide_type. E.g. creation of a new “Address Book”.   Note: Each user is limited to 500 WebAides of each type. Trying to create more will result in an error being returned.  See also [WebAide definitions](/rest-api/webaides.html).  {{ACL: Access to that specific type of WebAides; Add/Update Accessible WebAides and Entries }}

### Example
```python
from __future__ import print_function
import time
import luxsci
from luxsci.rest import ApiException
from pprint import pprint

# create an instance of the API class
secret_key = "SECRET_KEY"
token = "TOKEN"

luxsci_client = luxci.Client(secret_key, token)
api_instance = luxsci_client.WebAidesApi

username = 'username_example' # str | 
webaide_type = 'webaide_type_example' # str | 
body = luxsci.WebaidesWebaideTypeBody() # WebaidesWebaideTypeBody |  (optional)

try:
    api_response = api_instance.new_web_aide(username, webaide_type, body=body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling WebAidesApi->new_web_aide: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **str**|  | 
 **webaide_type** | **str**|  | 
 **body** | [**WebaidesWebaideTypeBody**](WebaidesWebaideTypeBody.md)|  | [optional] 

### Return type

[**InlineResponse20023**](InlineResponse20023.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **new_web_aide_entry**
> InlineResponse20024 new_web_aide_entry(username, webaide_type, webaide_id, body=body)



Create a new WebAide Entry. Note that invalid fields may simply be ignored, rather than generate an actual error. E.g. an invalid “E-mail Address” field will simply result in that field being omitted in the new entry. We recommend that you validate your own data and not rely on request errors to do the validation for you.  Note: Each WebAide is limited to 25,000 entries by default. If your WebAide has this many entries (or more), then this NewWebAideEntry command will return an error. If you need larger WebAides, please contact support. Very large WebAides may require the use of a dedicated server.  See also [WebAide definitions](/rest-api/webaides.html).  {{ACL: Access to that specific type of WebAides; Add/Change Accessible WebAides and Entries }}

### Example
```python
from __future__ import print_function
import time
import luxsci
from luxsci.rest import ApiException
from pprint import pprint

# create an instance of the API class
secret_key = "SECRET_KEY"
token = "TOKEN"

luxsci_client = luxci.Client(secret_key, token)
api_instance = luxsci_client.WebAidesApi

username = 'username_example' # str | 
webaide_type = 'webaide_type_example' # str | 
webaide_id = 'webaide_id_example' # str | 
body = luxsci.WebaideTypeWebaideIdBody() # WebaideTypeWebaideIdBody |  (optional)

try:
    api_response = api_instance.new_web_aide_entry(username, webaide_type, webaide_id, body=body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling WebAidesApi->new_web_aide_entry: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **str**|  | 
 **webaide_type** | **str**|  | 
 **webaide_id** | **str**|  | 
 **body** | [**WebaideTypeWebaideIdBody**](WebaideTypeWebaideIdBody.md)|  | [optional] 

### Return type

[**InlineResponse20024**](InlineResponse20024.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **update_web_aide_entry**
> InlineResponse20025 update_web_aide_entry(username, webaide_type, webaide_id, entry_id, body=body)



Update an existing WebAide Entry. This function will replace the data in all entry fields with the new data supplied. It is recommended that you retrieve the complete entry, alter it, and then update it – so that you update does not delete data from an entry simply because you did not include those fields in your update.  File attachments on entries are unaffected by this command.   See also [WebAide definitions](/rest-api/webaides.html).  {{ACL: Access to that specific type of WebAides; Add/Change Accessible WebAides and Entries }}

### Example
```python
from __future__ import print_function
import time
import luxsci
from luxsci.rest import ApiException
from pprint import pprint

# create an instance of the API class
secret_key = "SECRET_KEY"
token = "TOKEN"

luxsci_client = luxci.Client(secret_key, token)
api_instance = luxsci_client.WebAidesApi

username = 'username_example' # str | 
webaide_type = 'webaide_type_example' # str | 
webaide_id = 'webaide_id_example' # str | 
entry_id = 'entry_id_example' # str | 
body = luxsci.WebaideIdEntryIdBody() # WebaideIdEntryIdBody |  (optional)

try:
    api_response = api_instance.update_web_aide_entry(username, webaide_type, webaide_id, entry_id, body=body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling WebAidesApi->update_web_aide_entry: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **str**|  | 
 **webaide_type** | **str**|  | 
 **webaide_id** | **str**|  | 
 **entry_id** | **str**|  | 
 **body** | [**WebaideIdEntryIdBody**](WebaideIdEntryIdBody.md)|  | [optional] 

### Return type

[**InlineResponse20025**](InlineResponse20025.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

